@@ -81,6 +81,7 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('DEFAULT/enable_instance_password').with('value' => '<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/password_length').with('value' => '<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/allow_resize_to_same_host').with('value' => false)
+        is_expected.to contain_nova_config('DEFAULT/pci_alias').with(:value => '<SERVICE DEFAULT>')
       end
 
       it 'unconfigures neutron_metadata proxy' do
@@ -125,7 +126,6 @@ describe 'nova::api' do
           :enable_network_quota                 => false,
           :enable_instance_password             => true,
           :password_length                      => 12,
-          :pci_alias                            => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\",\"name\":\"graphic_card\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"name\":\"network_card\"}]",
           :allow_resize_to_same_host            => true,
         })
       end
@@ -189,14 +189,56 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('DEFAULT/password_length').with('value' => '12')
         is_expected.to contain_nova_config('DEFAULT/allow_resize_to_same_host').with('value' => true)
       end
+    end
 
+    context 'with pci_alias array' do
+      before do
+        params.merge!({
+          :pci_alias => [{
+              "vendor_id"  => "8086",
+              "product_id" => "0126",
+              "name"       => "graphic_card"
+            },
+            {
+              "vendor_id"  => "9096",
+              "product_id" => "1520",
+              "name"       => "network_card"
+            }
+          ]
+        })
+      end
       it 'configures nova pci_alias entries' do
         is_expected.to contain_nova_config('DEFAULT/pci_alias').with(
-          'value' => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\",\"name\":\"graphic_card\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"name\":\"network_card\"}]"
+          'value' => ['{"vendor_id":"8086","product_id":"0126","name":"graphic_card"}','{"vendor_id":"9096","product_id":"1520","name":"network_card"}']
         )
       end
     end
 
+    context 'with pci_alias JSON encoded string (deprecated)' do
+      before do
+        params.merge!({
+          :pci_alias => "[{\"vendor_id\":\"8086\",\"product_id\":\"0126\",\"name\":\"graphic_card\"},{\"vendor_id\":\"9096\",\"product_id\":\"1520\",\"name\":\"network_card\"}]",
+        })
+      end
+      it 'configures nova pci_alias entries' do
+        is_expected.to contain_nova_config('DEFAULT/pci_alias').with(
+          'value' => ['{"vendor_id":"8086","product_id":"0126","name":"graphic_card"}','{"vendor_id":"9096","product_id":"1520","name":"network_card"}']
+        )
+      end
+    end
+
+    context 'when pci_alias is empty' do
+      before do
+        params.merge!({
+          :pci_alias => ""
+        })
+      end
+
+      it 'clears pci_alias configuration' do
+        is_expected.to contain_nova_config('DEFAULT/pci_alias').with(:value => '<SERVICE DEFAULT>')
+      end
+    end
+
     context 'while validating the service with default command' do
       before do
         params.merge!({
