@@ -45,6 +45,10 @@ describe 'nova::migration::libvirt' do
       it { is_expected.not_to contain_file_line('/etc/libvirt/libvirtd.conf auth_tls')}
       it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf auth_tcp').with(:line => "auth_tcp = \"none\"") }
       it { is_expected.to contain_nova_config('libvirt/live_migration_tunnelled').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_completion_timeout').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_progress_timeout').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tcp://%s/system') }
+
     end
 
     context 'with override_uuid enabled' do
@@ -64,7 +68,7 @@ describe 'nova::migration::libvirt' do
       }).that_requires('Package[libvirt]').that_notifies('Service[libvirt]') }
     end
 
-    context 'with tls enabled' do
+    context 'with tls enabled (legacy)' do
       let :params do
         {
           :use_tls => true,
@@ -77,13 +81,30 @@ describe 'nova::migration::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tls://%s/system')}
     end
 
+    context 'with tls enabled' do
+      let :params do
+        {
+          :transport => 'tls',
+        }
+      end
+      it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls').with(:line => "listen_tls = 1") }
+      it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp').with(:line => "listen_tcp = 0") }
+      it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf auth_tls').with(:line => "auth_tls = \"none\"") }
+      it { is_expected.not_to contain_file_line('/etc/libvirt/libvirtd.conf auth_tcp')}
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tls://%s/system')}
+    end
+
     context 'with migration flags set' do
       let :params do
         {
-          :live_migration_tunnelled => true,
+          :live_migration_tunnelled          => true,
+          :live_migration_completion_timeout => '1500',
+          :live_migration_progress_timeout   => '1500',
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_tunnelled').with(:value => true) }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_completion_timeout').with_value('1500') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_progress_timeout').with_value('1500') }
     end
 
     context 'with auth set to sasl' do
@@ -100,7 +121,7 @@ describe 'nova::migration::libvirt' do
       let :params do
         {
           :auth    => 'sasl',
-          :use_tls => true
+          :transport => 'tls'
         }
       end
       it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf auth_tls').with(:line => "auth_tls = \"sasl\"") }
@@ -124,17 +145,27 @@ describe 'nova::migration::libvirt' do
         }
       end
       it { is_expected.not_to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls') }
+      it { is_expected.not_to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp') }
     end
 
     context 'when not configuring nova and tls enabled' do
       let :params do
         {
           :configure_nova => false,
-          :use_tls        => true,
+          :transport      => 'tls',
         }
       end
       it { is_expected.not_to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tls://%s/system') }
     end
+
+    context 'with listen_address set' do
+      let :params do
+        {
+          :listen_address => "127.0.0.1"
+        }
+      end
+      it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_address').with(:line => "listen_addr = \"127.0.0.1\"") }
+    end
   end
 
   # TODO (degorenko): switch to on_supported_os function when we got Xenial
@@ -177,4 +208,54 @@ describe 'nova::migration::libvirt' do
     it { is_expected.to contain_file_line('/etc/sysconfig/libvirtd libvirtd args').with(:line => 'LIBVIRTD_ARGS="--listen"') }
   end
 
+  shared_examples_for 'ssh tunneling' do
+
+    context 'with ssh transport' do
+      let :params do
+        {
+          :transport => 'ssh',
+        }
+      end
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s/system')}
+      it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls').with(:line => "listen_tls = 0") }
+      it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp').with(:line => "listen_tcp = 0") }
+    end
+
+    context 'with ssh transport with user' do
+      let :params do
+        {
+          :transport => 'ssh',
+          :client_user => 'foobar'
+        }
+      end
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://foobar@%s/system')}
+      it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls').with(:line => "listen_tls = 0") }
+      it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp').with(:line => "listen_tcp = 0") }
+    end
+
+    context 'with ssh transport with port' do
+      let :params do
+        {
+          :transport => 'ssh',
+          :client_port => 1234
+        }
+      end
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s:1234/system')}
+      it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls').with(:line => "listen_tls = 0") }
+      it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp').with(:line => "listen_tcp = 0") }
+    end
+
+    context 'with ssh transport with extraparams' do
+      let :params do
+        {
+          :transport => 'ssh',
+          :client_extraparams => {'foo' => '%', 'bar' => 'baz'}
+        }
+      end
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s/system?foo=%%25&bar=baz')}
+      it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls').with(:line => "listen_tls = 0") }
+      it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp').with(:line => "listen_tcp = 0") }
+    end
+
+  end
 end
